from sys import stdin

from caty.main import main


def dump_csv():
    try:
        main(stdin, 'csv')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_ini():
    try:
        main(stdin, 'ini')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_json():
    try:
        main(stdin, 'json')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_pickle():
    try:
        main(stdin, 'pickle')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_db():
    try:
        main(stdin, 'db')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_toml():
    try:
        main(stdin, 'toml')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_txt():
    try:
        main(stdin, 'txt')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_yaml():
    try:
        main(stdin, 'yaml')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_bin():
    try:
        main(stdin, 'bin')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_oct():
    try:
        main(stdin, 'oct')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_dec():
    try:
        main(stdin, 'dec')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_hex():
    try:
        main(stdin, 'hex')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_config():
    try:
        main(stdin, 'config')
    except Exception as x:
        print(f'\n ! {x} !\n')


def dump_html():
    try:
        main(stdin, 'html')
    except Exception as x:
        print(f'\n ! {x} !\n')




from sys import stdin

from caty.plugins import Plugins
from caty.main import main


head = '''
from sys import stdin

from caty.main import main

'''.lstrip()

tpl = r'''
def dump_{ext}():
    try:
        main(stdin, '{ext}')
    except Exception as x:
        print(f'\n ! {{x}} !\n')

'''

def gen():
    exts = [Plugin.ext[0] for Plugin in Plugins]
    with open('dump.py', 'w') as dump, open('../pyproject.toml', 'a') as prj:
        dump.write(head)
        for ext in exts:
            dump.write(tpl.format(**locals()))
            prj.write(f'dump_{ext} = "caty.dump:dump_{ext}"\n')


if __name__ == '__main__': gen()



from .base import FileReader, DataDumper


class CSV(FileReader, DataDumper):
    ext = 'csv',

    def load_file(self, path):
        from csv import Sniffer, DictReader
        with open(path, newline='') as inp:
            guess = Sniffer().sniff(inp.read())
            inp.seek(0)
            data = list(DictReader(inp, dialect=guess))
        return data
